@@ -23,13 +23,17 @@ import com.github.ajalt.clikt.core.CliktCommand
 import com.github.ajalt.clikt.core.ProgramResult
 import com.github.ajalt.clikt.parameters.arguments.argument
 import com.github.ajalt.clikt.testing.test
+import io.ktor.http.URLBuilder
+import io.ktor.http.takeFrom
 import io.ktor.client.*
 import io.ktor.client.engine.cio.*
 import kotlinx.coroutines.runBlocking
+import kotlinx.serialization.Serializable
 import tech.libeufin.nexus.LibeufinNexusCommand
 import tech.libeufin.nexus.loadBankKeys
 import tech.libeufin.nexus.loadClientKeys
 import tech.libeufin.nexus.loadConfig
+import tech.libeufin.nexus.loadJsonFile
 import kotlin.io.path.*
 
 val nexusCmd = LibeufinNexusCommand()
@@ -64,6 +68,11 @@ data class Kind(val name: String, val settings: String?) {
     val test get() = settings != null
 }
 
+@Serializable
+data class Config(
+    val payto: Map<String, String>
+)
+
 class Cli : CliktCommand("Run integration tests on banks provider") {
     val platform by argument()
 
@@ -105,6 +114,10 @@ class Cli : CliktCommand("Run integration tests on banks provider") {
             else -> Kind("Unknown", null)
         }
 
+        // Read testbench config 
+        val benchCfg: Config = loadJsonFile(Path("test/config.json"), "testbench config")
+            ?: Config(emptyMap())
+
         // Prepare cmds
         val log = "DEBUG"
         val flags = " -c $conf -L $log"
@@ -113,9 +126,16 @@ class Cli : CliktCommand("Run integration tests on banks provider") {
         val bankKeysPath = cfg.requirePath("nexus-ebics", "bank_public_keys_file")
         val currency = cfg.requireString("nexus-ebics", "currency")
 
-        // Alternative payto ?
-        val payto = "payto://iban/CH6208704048981247126?receiver-name=Grothoff%20Hans"
+        val dummyPaytos = mapOf(
+            "CHF" to "payto://iban/CH4189144589712575493?receiver-name=John%20Smith",
+            "EUR" to "payto://iban/DE54500105177452372744?receiver-name=John%20Smith"
+        )
+        val dummyPayto = dummyPaytos[currency] 
+            ?: throw Exception("Missing dummy payto for $currency")
+        val payto = benchCfg.payto[currency] ?: dummyPayto
+                        ?: throw Exception("Missing test payto for $currency")
         
+        val recoverDoc = "report statement notification"
         runBlocking {
             step("Init ${kind.name}")
 
@@ -136,11 +156,16 @@ class Cli : CliktCommand("Run integration tests on banks provider") {
                     })
                 }
                 put("reset-db", "dbinit -r $flags")
-                put("recover", "Recover old transactions", "ebics-fetch $ebicsFlags --pinned-start 2024-01-01 notification")
+                put("recover", "Recover old transactions", "ebics-fetch $ebicsFlags --pinned-start 2024-01-01 $recoverDoc")
                 put("fetch", "Fetch all documents", "ebics-fetch $ebicsFlags")
                 put("ack", "Fetch CustomerAcknowledgement", "ebics-fetch $ebicsFlags acknowledgement")
                 put("status", "Fetch CustomerPaymentStatusReport", "ebics-fetch $ebicsFlags status")
+                put("report", "Fetch BankToCustomerAccountReport", "ebics-fetch $ebicsFlags report")
                 put("notification", "Fetch BankToCustomerDebitCreditNotification", "ebics-fetch $ebicsFlags notification")
+                put("statement", "Fetch BankToCustomerStatement", "ebics-fetch $ebicsFlags statement")
+                put("list-incoming", "List incoming transaction", "testing list $flags incoming")
+                put("list-outgoing", "List outgoing transaction", "testing list $flags outgoing")
+                put("list-initiated", "List initiated payments", "testing list $flags initiated")
                 put("submit", "Submit pending transactions", "ebics-submit $ebicsFlags")
                 put("setup", "Setup", "ebics-setup $flags")
                 put("reset-keys", suspend {
@@ -153,7 +178,7 @@ class Cli : CliktCommand("Run integration tests on banks provider") {
                 if (kind.test) {
                     put("tx", suspend {
                         step("Submit one transaction")
-                        nexusCmd.run("initiate-payment $flags \"$payto&amount=CHF:42&message=single%20transaction%20test\"")
+                        nexusCmd.run("initiate-payment $flags \"$payto&amount=$currency:42&message=single%20transaction%20test\"")
                         nexusCmd.run("ebics-submit $ebicsFlags")
                         Unit
                     })
@@ -168,12 +193,25 @@ class Cli : CliktCommand("Run integration tests on banks provider") {
                 } else {
                     put("tx", suspend {
                         step("Submit new transaction")
-                        // TODO interactive payment editor
                         nexusCmd.run("initiate-payment $flags \"$payto&amount=$currency:1.1&message=single%20transaction%20test\"")
                         nexusCmd.run("ebics-submit $ebicsFlags")
                         Unit
                     })
                 }
+                put("tx-bad-name", suspend {
+                    val badPayto = URLBuilder().takeFrom(payto)
+                    badPayto.parameters.set("receiver-name", "John Smith")
+                    step("Submit new transaction with a bad name")
+                    nexusCmd.run("initiate-payment $flags \"$badPayto&amount=$currency:1.1&message=This%20should%20fail%20because%20bad%20name\"")
+                    nexusCmd.run("ebics-submit $ebicsFlags")
+                    Unit
+                })
+                put("tx-dummy", suspend {
+                    step("Submit new transaction to a dummy IBAN")
+                    nexusCmd.run("initiate-payment $flags \"$dummyPayto&amount=$currency:1.1&message=This%20should%20fail%20because%20dummy\"")
+                    nexusCmd.run("ebics-submit $ebicsFlags")
+                    Unit
+                })
             }
             while (true) {
                 var clientKeys = loadClientKeys(clientKeysPath)
